@@ -3,7 +3,7 @@ BEGIN {
   $MooX::Cmd::Role::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $MooX::Cmd::Role::VERSION = '0.005';
+  $MooX::Cmd::Role::VERSION = '0.006';
 }
 # ABSTRACT: MooX cli app commands do this
 
@@ -127,13 +127,13 @@ sub _initialize_from_cmd
 	});
 
 	my @args = $opts_record->records(join(' ',@ARGV));
-	my @used_args;
-	my $cmd;
+	my (@used_args, $cmd, $cmd_name);
 
 	defined $params{command_commands} or $params{command_commands} = $class->_build_command_commands(%params);
 	while (my $arg = shift @args) {
 		push @used_args, $arg and next unless $cmd = $params{command_commands}->{$arg};
 
+		my $cmd_name = $arg; # be careful about relics
 		use_module( $cmd );
 		$cmd->can($execute_method_name)
 		  or croak "you need an '".$execute_method_name."' function in ".$cmd;
@@ -149,7 +149,7 @@ sub _initialize_from_cmd
 	@ARGV = @used_args;
 	$params{command_args} = [ @args ];
 	$params{command_chain} = \@moox_cmd_chain; # later modification hopefully will modify ...
-	$params{command_name} = $cmd;
+	$params{command_name} = $cmd_name;
 	my $self = $creation_method->($class, %params);
 	$cmd and push @moox_cmd_chain, $self;
 
@@ -203,7 +203,7 @@ MooX::Cmd::Role - MooX cli app commands do this
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
